iterationtools.iterate_thread_from_component
============================================

.. autofunction:: abjad.tools.iterationtools.iterate_thread_from_component.iterate_thread_from_component
   :noindex:
